VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package DistPlotter

Package {DistPlotter}


Type: Package
Title: A Graphical User Interface for Plotting Common Univariate Distributions
Version: 0.0.2
Description: Package including an interactive Shiny application for plotting common univariate distributions.
License: MIT + file LICENSE
URL: https://github.com/ccasement/DistPlotter, https://CRAN.R-project.org/package=DistPlotter
BugReports: https://github.com/ccasement/DistPlotter/issues
Depends: R (≥ 3.5.0)
Imports: colourpicker (≥ 1.1.1), dplyr (≥ 1.0.8), DT (≥ 0.20), extraDistr (≥ 1.9.1), ggplot2 (≥ 3.3.5), rio (≥ 0.5.29), scales (≥ 1.1.1), shiny (≥ 1.7.1), shinyalert (≥ 3.0.0), shinyBS (≥ 0.61), shinyjs (≥ 2.1.0), shinyWidgets (≥ 0.6.4), stringi (≥ 1.7.6), stringr (≥ 1.4.0)
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2022-03-10 21:43:13 UTC; ccasement
Author: Christopher Casement [cre, aut], Grant Innerst [aut], Melissa Innerst [aut]
Maintainer: Christopher Casement <casementc@gmail.com>
Repository: CRAN
Date/Publication: 2022-03-10 22:10:17 UTC

DistPlotter: A Graphical User Interface for Plotting Common Univariate Distributions

Description

The DistPlotter package enables users to plot common univariate distributions and was designed with a particular focus on education. Users can plot distributions based on general shape (e.g., symmetric vs. skewed right) and distributions from common discrete and continuous families. They can also shade areas underneath the curve (e.g., areas corresponding to general probabilities, p-values, or confidence levels). Users can additionally plot their own quantitative data, as well as overlay a normal density curve and shade area(s) underneath.

Details

Package: DistPlotter
Type: Package
Version: 0.0.2
Date: 2022-03-09
Depends: R (>= 3.5.0)
Imports: colourpicker, dplyr, DT, extraDistr, ggplot2, rio, scales, shiny, shinyalert, shinyalert, shinyBS, shinyjs, shinyWidgets, stringi, stringr License: MIT
BugReports: https://github.com/ccasement/DistPlotter/issues
Encoding: UTF-8

Function

Author(s)

Christopher Casement
Department of Mathematics
Fairfield University
casementc@gmail.com

Grant Innerst
Department of Mathematics
Shippensburg University

Melissa Innerst
Department of Mathematics
Juniata College

See Also

Useful links:


Run the DistPlotter Shiny application

Description

Runs the DistPlotter Shiny application.

Usage

runDistPlotterApp()

Value

There is no return value.

Author(s)

Christopher Casement
Department of Mathematics
Fairfield University
casementc@gmail.com

Grant Innerst
Department of Mathematics
Shippensburg University

Melissa Innerst
Department of Mathematics
Juniata College

Examples

## only run the app in an interactive R session
if (interactive()) {runDistPlotterApp()}

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.